/*
 *  Copyright (C) 2006-2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_DOCK_H__
#define __KIBA_DOCK_H__

#define KIBA_TYPE_DOCK			(kiba_dock_get_type ())
#define KIBA_DOCK(obj)			(G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_DOCK, KibaDock))
#define KIBA_DOCK_CLASS(obj)		(G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_DOCK,  KibaDockClass))
#define KIBA_IS_DOCK(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_DOCK))
#define KIBA_IS_DOCK_CLASS(obj)		(G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_DOCK))
#define KIBA_DOCK_GET_CLASS		(G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_DOCK, KibaDockClass))

#ifndef __KIBA_H__
	typedef struct _KibaDock	KibaDock;
#endif
typedef struct _KibaDockClass		KibaDockClass;
typedef struct _KibaDockOptions		KibaDockOptions;

struct _KibaDock {
	GObject          parent_instance;
	
	KibaDockOptions  *options;
	
	gboolean       rerender;
	struct KibaDockSurface {
		cairo_surface_t  *surface;
		gboolean          needs_update;
	}bar;
};

struct _KibaDockOptions {
	gboolean         draw;
	gboolean         show_all_borders;
	gchar           *border_rgba;
	gchar           *background;
	gchar           *rgba_1;
	gchar           *rgba_2;
	gchar           *rgba_3;
	gchar           *corner_topleft;
	gchar           *corner_topright;
	gchar           *corner_bottomleft;
	gchar           *corner_bottomright;
	double           cap_margin;
	double           cap_size;
	double           margin;
	double           position_stepsize;
	double           border_width;
	double           bg_affection;
	double           bg_step_size;
	double           bg_radius_1;
	double           bg_radius_2;
	double           background_alpha;
	double           edge_radius;
};

struct _KibaDockClass {
	GObjectClass     parent_class;
};

/**
 * Creates and returns a new KibaDock.
 *
 * @return The KibaDock object created.
 */
KibaDock* kiba_dock_new (void);

/**
 * Check if a Object is in motion.
 *
 * @param dock The KibaDock object.
 * @param geometry The KibaGeometry object.
 * @param cr The Drawing Context for the Surface.
 */
void kiba_dock_update_surface (KibaDock     *dock,
                               KibaGeometry *geometry,
                               cairo_t      *cr);

/**
 * Check if a Object is in motion.
 *
 * @param geometry The KibaGeometry object.
 * @param window The Kiba Window.
 * @param use_strut @c TRUE when strut proberty should be set, otherwise
 *                  @c FALSE if the strut proberty should be unset.
 */
void kiba_dock_set_strut (KibaGeometry *geometry,
                          GdkWindow    *window,
                          gboolean     use_strut);

#endif
