/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-kiba.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-kiba.org>
*/

#ifndef __KIBA_TITEL_H__
#define __KIBA_TITEL_H__

#include <gdk/gdk.h>

#define KIBA_TYPE_TITEL			(kiba_titel_get_type ())
#define KIBA_TITEL(obj)			(G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_TITEL, KibaTitel))
#define KIBA_TITEL_CLASS(obj)		(G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_TITEL,  KibaTitelClass))
#define KIBA_IS_TITEL(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_TITEL))
#define KIBA_IS_TITEL_CLASS(obj)	(G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_TITEL))
#define KIBA_TITEL_GET_CLASS		(G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_TITEL, KibaTitelClass))

#ifndef __KIBA_H__
	typedef struct _KibaTitel	KibaTitel;
#endif
typedef struct _KibaTitelOptions	KibaTitelOptions;
typedef struct _KibaTitelClass		KibaTitelClass;

struct _KibaTitel {
	KibaTitelOptions *options;
	GdkRectangle     geometry;           /* saves the aim geometry */
	GdkRectangle     geometry_animate;   /* saves the geometry while animating */
	double           fade_alpha;         /* stores the fade_alpha (0.0 when not shown) */
	char             *text;              /* stores the last rendered text (unallocated pointer to object->name) */
};

struct _KibaTitelOptions {
	gboolean         enable;
	gchar           *rgba;
	gchar           *shadow_rgba;
	gchar           *bg_rgba_1;
	gchar           *bg_rgba_2;
	gchar           *bg_rgba_3;
	gchar           *border_rgba;
	gchar           *background;
	gchar           *border_style;
	gchar           *placement_x;
	gchar           *placement_y;
	gchar           *font;
	double           shadow_offset;
	double           position_stepsize;
	double           icon_padding;
	double           hide_delay;
	double           bg_radius_1;
	double           bg_radius_2;
	double           bg_step_size;
	double           bg_affection;
	double           border_width;
};

struct _KibaTitelClass {
	GObjectClass	parent_class;
};

/**
 * Creates and returns a new KibaTitel.
 *
 * @return The KibaTitel object created.
 */
KibaTitel* kiba_titel_new (void);

/**
 */
void kiba_titel_paint (KibaTitel *titel,
                       KibaObject *object,
                       cairo_t *cr,
                       KibaGeometry *geometry,
                       KibaObject *dragging_object,
                       KibaObject *prelight_object);

/**
 * Update KibaObject Surface Buffer.
 *
 * @param titel The KibaTitel object.
 * @param titel The KibaGeometry object.
 * @param titel The KibaObject.
 * @param cr The Drawing Context.
 */
void kiba_titel_update_surface (KibaTitel  *titel,
                                KibaGeometry *geometry,
                                KibaObject *object,
                                cairo_t    *cr);

/**
 * Update PangoLayout.
 *
 * @param titel The KibaTitel object.
 * @param cr The Drawing Context.
 * @param layout The PangoLayout.
 * @param text The new text.
 * @param description The new Description.
 */
void kiba_titel_update_pango_layout (KibaTitel   *titel,
                                     cairo_t     *cr,
                                     PangoLayout **layout,
                                     const char  *text,
                                     const char  *description);

#endif
