/*
 *  Copyright (C) 2006-2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_H__
#define __KIBA_H__

#include "../config.h"
#ifdef HAVE_GLITZ
#ifdef CAIRO_HAS_GLITZ_SURFACE
  #define USE_GLITZ
#endif
#endif

#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <cairo.h>
#ifdef USE_GLITZ
  #include <glitz-glx.h>
  #include <cairo-glitz.h>
#endif

#define KIBA_ERROR		(kiba_error_quark ())
#define KIBA_TYPE		(kiba_get_type ())
#define KIBA(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE, Kiba))
#define KIBA_CLASS(obj)		(G_TYPE_CHECK_CLASS_CAST ((obj), KIBA,  KibaClass))
#define IS_KIBA(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE))
#define KIBA_IS_CLASS(obj)	(G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE))
#define KIBA_GET_CLASS		(G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE, KibaClass))

/* flags macro's */
#define SET_FLAG(s,x)		(s |= (1 << x))
#define DEL_FLAG(s,x)		(s = s & ~(1<<x))
#define GET_FLAG(s,x)		(s & (1<<x))

#define ICON_THEME		(gtk_icon_theme_get_default ())
#define FADE_STEP		(0.01)
#define SECOND_INTERVAL		(1000)
#define MINUTE_INTERVAL		(60000)
#define QUIT_STEPSIZE		(10)

typedef struct _Kiba			Kiba;
typedef struct _KibaClass		KibaClass;
typedef struct _KibaOptions		KibaOptions;
typedef struct _KibaDock		KibaDock;
typedef struct _KibaTitel		KibaTitel;
typedef struct _KibaSurface		KibaSurface;
typedef struct _KibaGeometry		KibaGeometry;
typedef struct _KibaObject		KibaObject;
typedef struct _KibaPlugin		KibaPlugin;
typedef struct _KibaAkamaruObject	KibaAkamaruObject;
typedef struct _PrefMember		PrefMember;
typedef struct _KibaScreen		KibaScreen;

enum {
	KIBA_QUIT = 0,
	KIBA_ENTERED,
	KIBA_PHYSICS,
	KIBA_DRAGGING,
	KIBA_HIDING,
	KIBA_SHAPED,
	KIBA_MOVING,
};

struct _Kiba {
	GtkWidget     widget;     /* class widget */
	int           flags;      /* state FLAGS */
	
	KibaDock      *dock;
	KibaScreen    *screen;
	KibaTitel     *titel;            /* titel proberty struct */
	KibaGeometry  *geometry;         /* geometry struct */
	GList         *objects;          /* List of all KibaObject's */
	GList         *removed_objects;  /* List with removed KibaObject's */
	
	/* options */
	KibaOptions    *settings;          /* settings struct */
	char           *settings_file;     /* stores the setting file content. */
	
	KibaObject     *dragging_object;     /* the currently dragged object or NULL */
	KibaObject     *prelight_object;     /* the currently prelighted object or NULL */
	KibaObject     *exec_object;         /* the current exec object or NULL */
	
	/* rendering related variables */
	GdkPixmap      *pixmap;
	GdkGC          *gc;
#ifdef USE_GLITZ
	glitz_drawable_format_t  *glitz_draw_format;
	glitz_drawable_t         *glitz_drawable;
	glitz_format_t           *glitz_format;
#endif
	struct KibaPrelightSurface {
		cairo_surface_t  *surface;
		gboolean          needs_update;
	}prelight;
	struct KibaProgressSurface {
		cairo_surface_t  *surface;
		gboolean          needs_update;
	}progress;
	struct KibaBubbleSurface {
		cairo_surface_t  *surface;
		gboolean          needs_update;
	}bubble;
	struct KibaTriangleSurface {
		cairo_surface_t  *surface;
		gboolean          needs_update;
	}triangle;
	struct KibaArrowSurface {
		cairo_surface_t  *surface;
		gboolean          needs_update;
	}arrow;
	struct KibaSeperatorSurface {
		cairo_surface_t  *surface;
		gboolean          needs_update;
	}seperator;
	
	/* drag animation */
	GdkRectangle        drag_geometry;
	gboolean            drag_motion;
	double              drag_window_offset;
	double              drag_alpha;
	
	/* parameter */
	char       *cwd;         /* current working directory */
	gboolean    benchmark;
	int         redraws;
	int         events;
};

struct _KibaOptions {
	gboolean         keep_window_below_others;
	double           object_animate_stepsize;
	gboolean         object_fade_enable;
	double           object_fade_step;
	double           object_fade_alpha;
	
	/* Notification Bubble */
	gboolean         bubble_enable;
	gchar           *bubble_bg_rgba_1;
	gchar           *bubble_bg_rgba_2;
	gchar           *bubble_bg_rgba_3;
	gchar           *bubble_text_rgba;
	gchar           *bubble_background;
	gchar           *bubble_border_rgba;
	gchar           *bubble_border_style;
	gchar           *bubble_font;
	double           bubble_border_width;
	double           bubble_bg_affection ;
	double           bubble_bg_radius_1;
	double           bubble_bg_radius_2;
	
	/* Notification Rectangle */
	gboolean         notification_triangle_enable;
	gchar           *notification_triangle_rgba;
	
	/* progress drawing */
	gboolean         progress_enable;
	
	/* AUTOHIDE */
	gboolean         auto_hide_enable;
	double           auto_hide_area;
	double           auto_hide_delay;
	double           auto_hide_speed;
	
	gchar            *mouse_over_effect;
	
	/* PULSE */
	gboolean         pulse_exec_enable;
	double           pulse_exec_stepsize;
	double           pulse_exec_zoom_factor;
	double           pulse_stepsize;
	double           pulse_max_alpha;
	double           pulse_scale_factor;
	
	/* ZOOM */
	double           zoom_scale_factor;
	double           zoom_max_stepsize;
	double           zoom_area_factor;
	
	/* ROTATE */
	gboolean         mouseover_rotating;
	gboolean         exec_rotate_enable;
	gboolean         rotate_on_object_adding;
	double           mouseover_rotate_velocity;
	double           exec_rotate_velocity;
	double           rotate_scale_factor;
	
	/* BOUNCING */
	double           bounce_height;
	double           mouseover_bouncing_height;
	
	/* PRELIGHT */
	gboolean         prelight_enable;
	gchar           *prelight_rgba;
	
	/* Seperator */
	gboolean         seperator_draw;
	gchar           *seperator_rgba;
	gchar           *seperator_inner_rgba;
	double           seperator_inner_size;
};

struct _KibaClass {
	GtkWidgetClass     parent_class;
};

/**
 * Creates and returns a new Kiba Widget.
 *
 * @return The Kiba Widget created.
 */
GtkWidget* kiba_new (void);

/**
 * Hide Kiba (timeout).
 *
 * @return @c TRUE if Hide is not complete, otherwise
 *         @c FALSE.
 */
gint kiba_hide (gpointer data);

/**
 * UnHide Kiba (timeout).
 *
 * @return @c TRUE if UnHide is not complete, otherwise
 *         @c FALSE.
 */
gint kiba_unhide (gpointer data);

/**
 * Update Widget Geometry.
 *
 * @param dock The Kiba Widget.
 */
void kiba_update_geometry (Kiba *dock);

#endif
